# Spidex

Spidex is the Python client for the Spidex protocol. It allows you to trade and fetch data from Spidex using Python.

## Installation

```
cd ./spidex
```
```
pip install -r requirements.txt
```
```
python setup.py build
```
```
python setup.py install
```
### Successfuly Install Spidex, then you can use spidex api
Note: requires Python >= 3.6.

## Examples
```
from spidex.api import SpidexClient
```
## Test
- about sign_request, You can refer to ```./examples/test_pubilc_private/private.py```
- about public_request, You can refer to ```./examples/test_pubilc_private/public.py```
- about websocket, You can refer to ```./examples/test_websocket```





